/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2012 CASSIDIAN, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.core.annotator;

import java.io.File;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.net.URI;
import java.net.URISyntaxException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import java.util.Locale;

import junit.framework.Assert;

import org.apache.commons.logging.LogFactory;
import org.geonames.www.ontology.WGeonamesAnnotator;
import org.junit.Test;
import org.ow2.weblab.core.annotator.AbstractAnnotator.Operator;
import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.exception.WebLabUncheckedException;
import org.ow2.weblab.core.extended.factory.WebLabResourceFactory;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.model.Document;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.core.model.WModelAnnotator;
import org.ow2.weblab.core.model.processing.WProcessingAnnotator;
import org.ow2.weblab.core.model.retrieval.WRetrievalAnnotator;
import org.ow2.weblab.rdf.Value;
import org.purl.dc.elements.DublinCoreAnnotator;
import org.purl.dc.terms.DCTermsAnnotator;
import org.w3.owl.OWLAnnotator;
import org.w3.www.ma_ont.MAOntAnnotator;

public class TestAnnotators {


	@Test
	public void testAnnotators() throws IllegalArgumentException, IllegalAccessException, InvocationTargetException, URISyntaxException {
		final Document doc = WebLabResourceFactory.createResource("ref", "test", Document.class);
		final BaseAnnotator[] bas = new BaseAnnotator[] { new WProcessingAnnotator(doc), new WRetrievalAnnotator(doc), new WGeonamesAnnotator(doc),
				new BaseAnnotator(doc), new DCTermsAnnotator(doc), new WModelAnnotator(doc), new MAOntAnnotator(doc), new OWLAnnotator(doc),
				new DublinCoreAnnotator(doc) };
		final URI testuri = URI.create("test:test");
		final WProcessingAnnotator wpa = new WProcessingAnnotator(testuri, new PieceOfKnowledge());
		new WRetrievalAnnotator(testuri, new PieceOfKnowledge());
		new WGeonamesAnnotator(testuri, new PieceOfKnowledge());
		new BaseAnnotator(testuri, new PieceOfKnowledge());
		new DCTermsAnnotator(testuri, new PieceOfKnowledge());
		new WModelAnnotator(testuri, new PieceOfKnowledge());
		new OWLAnnotator(testuri, new PieceOfKnowledge());
		new MAOntAnnotator(testuri, new PieceOfKnowledge());
		new DublinCoreAnnotator(testuri, new PieceOfKnowledge());

		for (final BaseAnnotator base : bas) {
			this.browseAnnotator(base);
		}

		Assert.assertTrue(wpa.isAppendMode());
		wpa.startInnerAnnotatorOn(URI.create("none:none"));
		wpa.endInnerAnnotator();
		wpa.setResource(doc);
		wpa.endInnerAnnotator();
		Assert.assertFalse(wpa.isInnerAnnotatorStarted());
		new WProcessingAnnotator(URI.create("none:er"), null);
		doc.setUri("not an uri");
		new WProcessingAnnotator(doc);

	}


	@Test
	public void testDCAnnotatorOnOneDoc() throws WebLabCheckedException {
		final Document doc = WebLabResourceFactory.createResource("test", "doc", Document.class);
		final DublinCoreAnnotator annot = new DublinCoreAnnotator(doc);
		annot.writeLanguage("eng");
		new WebLabMarshaller().marshalResource(doc, new File("./target/test.xml"));
		Assert.assertEquals("eng", annot.readLanguage().firstTypedValue());
	}


	private void browseAnnotator(final BaseAnnotator base) throws IllegalArgumentException, IllegalAccessException, InvocationTargetException,
			URISyntaxException {
		final List<Method> write = new LinkedList<Method>();
		final List<Method> read = new LinkedList<Method>();
		for (final Method f : base.getClass().getDeclaredMethods()) {
			if (f.getName().startsWith("read")) {
				read.add(f);
			} else if (f.getName().startsWith("write")) {
				write.add(f);
			}
		}

		for (final Method wm : write) {
			wm.invoke(base, this.getParameter(wm.getParameterTypes()[0]));
		}

		for (final Method wm : read) {
			final Value<?> o = (Value<?>) wm.invoke(base);

			Assert.assertNotNull("Error for ppt " + wm.getName() + " in class " + base.getClass().getName(), o);
			Assert.assertTrue("Error for ppt " + wm.getName() + " in class " + base.getClass().getName(), o.getValues().size() > 0);
			final Object z = o.getValues().getFirst();
			final Object res = this.getParameter(z.getClass());
			Assert.assertEquals("Error for ppt " + wm.getName() + " in class " + base.getClass().getName(), res, z);
		}
	}


	private Object getParameter(final Class<?> clazz) throws URISyntaxException {
		final SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ssZ", Locale.ENGLISH);
		Date now = null;
		try {
			now = sdf.parse("2010-09-14T14:17:49+0200");
		} catch (final ParseException e1) {
			e1.printStackTrace();
		}
		final String test = "test";
		final URI uri = new URI("test:test");

		final Byte by = Byte.valueOf((byte) 3);
		final Byte[] bytes = new Byte[] { by, by, by };

		final Boolean b = Boolean.TRUE;
		final Integer t = Integer.valueOf(12);
		final Double d = Double.valueOf(0.241);
		final Long l = Long.valueOf(1235435431453453152l);
		final Float f = Float.valueOf(12354.54f);
		if (clazz.isInstance(now)) {
			return now;
		} else if (clazz.isInstance(uri)) {
			return uri;
		} else if (clazz.isInstance(test)) {
			return test;
		} else if (clazz.isInstance(l)) {
			return l;
		} else if (clazz.isInstance(t)) {
			return t;
		} else if (clazz.isInstance(d)) {
			return d;
		} else if (clazz.isInstance(b)) {
			return b;
		} else if (clazz.isInstance(by)) {
			return by;
		} else if (clazz.isInstance(f)) {
			return f;
		} else if (clazz.isInstance(bytes)) {
			return bytes;
		}
		LogFactory.getLog(this.getClass()).warn("Range type not taken into account in the test: " + clazz);
		return null;
	}


	@Test
	public void testT() throws WebLabCheckedException{
		final Resource res = new WebLabMarshaller().unmarshal(new File("./target/test.xml"), Resource.class);
		final DublinCoreAnnotator annotator = new DublinCoreAnnotator(res);
		Assert.assertEquals("eng", annotator.readLanguage().firstTypedValue());
		
		
	}
	
	@Test
	public void testAbstractAnnotator() {
		Document doc = new Document();
		doc.setUri("test://test");
		final BaseAnnotator ba = new BaseAnnotator(doc);
		Assert.assertEquals(doc, ba.getResource());
		ba.retrieveAnnotation(Operator.READ, null);
		ba.writeLabel("test");
		ba.retrieveAnnotation(Operator.READ, null);
		ba.retrieveAnnotation(Operator.ADD, null);
		ba.retrieveAnnotation(Operator.ADD, "test");
		
		ba.setAppendMode(false);
		ba.applyOperator(Operator.WRITE, "none", URI.create("nop://nop"), "none", String.class, null);
		ba.applyOperator(Operator.ADD, "none", URI.create("nop://nop"), "none", String.class, "test");

		try{
			ba.applyOperator(Operator.SET, "none", URI.create("nop://nop"), "none", String.class, "test");
			Assert.fail("SET Opertaor is defined");
		}catch (WebLabUncheckedException e) {
			// Normal
		}
		
		ba.applyOperator(Operator.READ, "none", URI.create("nop://nop"), "none", String.class, "test");
		
		doc.getAnnotation().clear();
		final BaseAnnotator ba2 = new BaseAnnotator(doc);
		ba2.startInnerAnnotatorOn(URI.create("dummy://dummy"));
		ba2.retrieveAnnotation(Operator.WRITE, null);
		
		doc.getAnnotation().clear();
		final BaseAnnotator ba3 = new BaseAnnotator(doc);
		ba3.startInnerAnnotatorOn(URI.create("dummy://dummy"));
		ba3.retrieveAnnotation(Operator.WRITE, "none");
	}
	
}
