/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.impl;

import java.util.Collection;
import java.util.Set;

import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.model.PieceOfKnowledge;

/**
 * THis class gives basic tools to retrieve Predicate, Value pairs and
 * to write statements from a WTripleMap
 * 
 * @author Arnaud
 * 
 */
public interface IPredicateValuePairs {


	/**
	 * Returns the object of the predicate.
	 * 
	 * @param predicate
	 *            a predicate
	 * @return the object
	 */
	public Object getValue(String predicate);


	/**
	 * Write a statement.
	 * 
	 * @param predicate
	 *            a predicate
	 * @param object
	 *            an object
	 * @throws WebLabCheckedException
	 */
	public void writeStatement(String predicate, String object) throws WebLabCheckedException;


	/**
	 * Write several statements at the same time.
	 * 
	 * @param predicates
	 *            an array of predicates
	 * @param objects
	 *            an array of objects
	 * @param pok
	 *            a piece of knowledge
	 * @throws WebLabCheckedException
	 */
	public void writeStatements(String[] predicates, String[] objects, PieceOfKnowledge pok) throws WebLabCheckedException;


	/**
	 * Returns all predicates
	 * 
	 * @return all predicates
	 */
	public Set<String> allPredicates();


	/**
	 * Returns the list of WTriples
	 * 
	 * @return the list of WTriples
	 */
	public Collection<WTriple> getStatements();
}
