/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.core.helper.impl.parser;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;

/**
 * RDFDateTypeParser is a TtpeParser for dates.
 * 
 * @author asaval
 *
 */
public class RDFDateTypeParser extends TypeParser<Date> {


	private static final String XSD_DATE_REGEXP = "\"(.|\\s)+\"\\^\\^xsd:date(@..(.|\\s)*)?";


	private static final Log LOG = LogFactory.getLog(RDFDateTypeParser.class);


	@Override
	protected Date parseTypeValue(final String value, final String type, final String lang) {

		try {
			final DateTimeFormatter parser = ISODateTimeFormat.dateTimeParser();
			return parser.parseDateTime(value).toDate();

		} catch (final Exception exception) {
			RDFDateTypeParser.LOG.warn("Can not parse " + value + " into a Date Java Object", exception);
		}

		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ssZ");
		try {

			return sdf.parse(value.trim());
		} catch (final ParseException exception) {
			sdf = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss");
			try {
				return sdf.parse(value.trim());
			} catch (final ParseException exception1) {
				RDFDateTypeParser.LOG.error(exception1);
			}

			RDFDateTypeParser.LOG.error(exception);
		}

		final int[] styles = new int[] { DateFormat.DEFAULT, DateFormat.SHORT, DateFormat.MEDIUM, DateFormat.LONG, DateFormat.FULL };
		final Locale[] locales = new Locale[] { Locale.ENGLISH, Locale.FRENCH, Locale.GERMAN };
		boolean found = false;
		Date date = null;
		int index = 0;
		int length = 0;
		while (!found) {
			try {
				if (length == locales.length) {
					break;
				}
				final DateFormat dateformat = DateFormat.getDateInstance(styles[index], locales[length]);
				index++;
				if (index == styles.length) {
					index = 0;
					length++;
				}
				date = dateformat.parse(value.trim());
				found = true;
			} catch (final ParseException pe) {
				RDFDateTypeParser.LOG.trace(pe);
			}
		}

		return date;
	}


	@Override
	protected boolean matches(final String object) {
		return object.trim().matches(RDFDateTypeParser.XSD_DATE_REGEXP);
	}

}
