/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.core.helper.impl.parser;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class RDFFloatTypeParser extends TypeParser<Float> {


	private static final String XSD_FLOAT_REGEXP = "\"(.|\\s)+\"\\^\\^xsd:float?(@..(.|\\s)*)?";


	private static final Log LOG = LogFactory.getLog(RDFFloatTypeParser.class);


	@Override
	protected boolean matches(final String object) {
		return object.trim().matches(RDFFloatTypeParser.XSD_FLOAT_REGEXP);
	}


	@Override
	protected Float parseTypeValue(final String value, final String type, final String lang) {
		Float float_value = null;
		try {
			float_value = Float.valueOf(value.trim());
		} catch (final NumberFormatException nfe) {
			RDFFloatTypeParser.LOG.error(nfe);
		}
		return float_value;
	}


}
