/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.impl;

import java.util.List;
import java.util.Set;

import junit.framework.Assert;

import org.junit.BeforeClass;
import org.junit.Test;
import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.extended.ontologies.RDF;
import org.ow2.weblab.core.extended.ontologies.RDFS;
import org.ow2.weblab.core.helper.impl.parser.Parsers;
import org.ow2.weblab.core.helper.impl.parser.ReflectChanger;
import org.ow2.weblab.core.helper.test.ResourcesCreator;
import org.ow2.weblab.core.model.Document;

public class ResultsTest {


	@BeforeClass
	public static void buildResources() throws WebLabCheckedException {
		if (!ResourcesCreator.DOCUMENT.exists()) {
			ResourcesCreator.buildTestResources();
		}
	}


	@Test
	public void testResults() throws WebLabCheckedException, SecurityException, IllegalArgumentException {
		this.resetParsers();

		final Document document = new WebLabMarshaller().unmarshal(ResourcesCreator.DOCUMENT, Document.class);
		SimpleSelector simpleSelector = RDFSelectorFactory.getSelector();
		Results results = simpleSelector.select(document);
		Assert.assertEquals(2, results.size());
		Set<String> uris = results.getSubjects(RDF.TYPE, null);
		Assert.assertEquals(1, uris.size());
		uris = results.getSubjects(null, null);
		Assert.assertEquals(2, uris.size());

		// Integer size = results.getTypedValue("weblab://fileRepository/1236093700390/res_603",
		// "http://weblab-project.org/core/model/property/hasOriginalFileSize" , Integer.class);
		// assertEquals(4404, size.intValue());

		List<String> values = results.getTypedValues(null, RDFS.LABEL, String.class);
		Assert.assertEquals(46, values.size());

		simpleSelector = RDFSelectorFactory.getSelector("weblab://test");
		simpleSelector.limitToFirstLevelAnnotation(true);
		results = simpleSelector.select(document);
		Assert.assertEquals(2, results.size());

		final Results r = new Results(results.statements);
		values = r.getTypedValues(null, RDFS.LABEL, String.class);
		Assert.assertEquals(46, values.size());
	}


	public void resetParsers() throws SecurityException, IllegalArgumentException {
		final Object result = ReflectChanger.invoke(null, Parsers.class, "loadParsers", true, new Object[0]);
		ReflectChanger.setField(null, Parsers.class, "parsers", result, true);
	}

}
