/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.impl;

import java.util.List;

import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;
import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.extended.ontologies.RDF;
import org.ow2.weblab.core.helper.test.ResourcesCreator;
import org.ow2.weblab.core.model.Document;

public class SelectionPerfTest {


	@BeforeClass
	public static void buildResources() throws WebLabCheckedException {
		if (!ResourcesCreator.DOCUMENT.exists()) {
			ResourcesCreator.buildTestResources();
		}
	}


	private static final Document doc = SelectionPerfTest.loadDoc();


	private static Document loadDoc() {
		if (!ResourcesCreator.DOCUMENT.exists()) {
			try {
				ResourcesCreator.buildTestResources();
			} catch (WebLabCheckedException e) {
				e.printStackTrace();
				Assert.fail(e.getLocalizedMessage());
			}
		}
		try {
			return new WebLabMarshaller().unmarshal(ResourcesCreator.DOCUMENT, Document.class);
		} catch (final WebLabCheckedException e) {
			e.printStackTrace();
			Assert.fail(e.getLocalizedMessage());
		}
		return null;
	}


	@Test
	public void testSimpleSelection() {
		final TripleSelectors ts = new TripleSelectors(true);
		final List<WTriple> l = ts.findInResource(SelectionPerfTest.doc, null, RDF.TYPE, null);
		Assert.assertFalse(l.isEmpty());
	}


	@Test
	public void testSimpleCSelection() {
		final ComplexTripleSelector cts = new ComplexTripleSelector();
		cts.supportNullData = true;
		final List<WTriple> l = cts.findInResource(SelectionPerfTest.doc, null, RDF.TYPE, null);
		Assert.assertFalse(l.isEmpty());
	}
}
