/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.impl;

import java.util.LinkedList;
import java.util.List;

import junit.framework.Assert;

import org.junit.Test;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.Resource;

import com.hp.hpl.jena.graph.Node;
import com.hp.hpl.jena.graph.Triple;

public class WTripleTest {

	@Test
	public void testWTriple() {
		final Node s = Node.createLiteral("sujet");
		final Node p = Node.createLiteral("pred");
		final Node o = Node.createLiteral("object");
		final Annotation a = new Annotation();

		final WTriple wt = new WTriple(s, p, o, "test", (Resource) null, new LinkedList<Resource>());
		Assert.assertFalse(wt.equals(new Object()));
		wt.getText();
		wt.setAnnotation(a);
		Assert.assertEquals(a, wt.from());

		final Triple t = new Triple(s, p, o);
		final WTriple wt2 = new WTriple(t, "sujet", (Resource) null, null);
		wt2.getTriple();

		final WTriple wt3 = new WTriple("", "", null, null, null, null);
		wt3.getAnnotatedOn();

		final WTriple wt4 = new WTriple("1", "", "", null, null, null);
		final WTriple wt5 = new WTriple("", "1", "", null, null, null);
		final WTriple wt6 = new WTriple("", "", "1", null, null, null);
		
		final WTriple wt7 = new WTriple(null, "", "", null, null, null);
		final WTriple wt8 = new WTriple("", null, "", null, null, null);
		final WTriple wt9 = new WTriple("", "", null, null, null, null);
		final WTriple wt10 = new WTriple("1", "", "", null, null, null);
		final WTriple wt11 = new WTriple("", "1", "", null, null, null);
		final WTriple wt12 = new WTriple("", "", "1", null, null, null);
		final WTriple wt13 = new WTriple("", "", "", null, null, null);
		
		Assert.assertFalse(wt4.equals(wt5));
		Assert.assertFalse(wt4.equals(wt6));
		Assert.assertFalse(wt5.equals(wt6));
		Assert.assertFalse(wt5.equals(wt4));
		Assert.assertFalse(wt6.equals(wt4));
		Assert.assertFalse(wt6.equals(wt5));
		Assert.assertFalse(wt7.equals(wt));
		Assert.assertFalse(wt8.equals(wt));
		Assert.assertFalse(wt9.equals(wt));
		Assert.assertTrue(wt4.equals(wt10));
		Assert.assertTrue(wt5.equals(wt11));
		Assert.assertTrue(wt6.equals(wt12));
		Assert.assertFalse(wt6.equals(wt13));

		final List<Resource> res = new LinkedList<Resource>();
		final Resource rs = new Resource();
		rs.setUri("\"sujet\"");
		final Resource rn = new Resource();
		final Resource ro = new Resource();
		ro.setUri("object");
		res.add(rs);
		res.add(rn);
		res.add(ro);
		res.add(null);
		final WTriple wt42 = new WTriple(t, "sujet", (Resource) null, res);
		Assert.assertFalse(wt6.equals(wt42));

		final Statements wtm = new Statements();
		wtm.add(wt);
		wtm.add(wt2);
		wtm.add(wt3);
		wtm.add(wt4);
		wtm.add(wt5);
		wtm.add(wt6);
		wtm.add(wt42);
		List<String> list = wtm.sortBy("none", Statements.ASC);
		Assert.assertTrue(list.isEmpty());
		
		Assert.assertEquals("\"sujet\": null\ntest \"pred\"\nobject: null", wt.toString());
		
		Resource r = new Resource();
		r.setUri("valid://uri");
		List<Resource> lr = new LinkedList<Resource>();
		lr.add(null);
		
		new WTriple(new Triple(Node.ANY, Node.ANY, Node.createLiteral("not uri")), "", null, lr);
		new WTriple(new Triple(Node.ANY, Node.ANY, Node.createLiteral("valid://uri")), "", null, lr);
		
		lr.clear();
		lr.add(r);
		new WTriple(new Triple(Node.createURI("valid://uri"), Node.ANY, Node.createLiteral("not uri")), "", null, lr);
		
		new WTriple(new Triple(Node.createURI("anotheruri"), Node.ANY, Node.createLiteral("valid://uri")), "", null, lr);
		
	}

}
