/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.impl.parser;

import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;

import org.apache.commons.logging.LogFactory;

public class DummyClassLoader extends ClassLoader {


	private String matches = "";


	public DummyClassLoader(final ClassLoader parent, final String pattern) {
		super(parent);
		this.matches = pattern;
	}


	public DummyClassLoader(final String pattern) {
		super(null);
		this.matches = pattern;
	}

	private Class<?> loadedClass = null;

	protected int dummyURLs = 0; // 0 standard, 1 dummy urls, 2 exception, 3 modified urlhandlers


	private static final int BUFFER_SIZE = 8192;


	@Override
	protected synchronized Class<?> loadClass(final String className, final boolean resolve) throws ClassNotFoundException {

		LogFactory.getLog(this.getClass()).info("Using Dummy Loader to loadClass: " + className);
		if (!className.matches(this.matches)) {
			return super.loadClass(className, resolve);
		}

		if (this.loadedClass != null){
			return this.loadedClass;
		}
		
		byte[] classBytes;
		try {
			final InputStream in = new FileInputStream("src/test/resources/Dummy.class");
			final byte[] buffer = new byte[DummyClassLoader.BUFFER_SIZE];
			final ByteArrayOutputStream out = new ByteArrayOutputStream();
			int n = -1;
			while ((n = in.read(buffer, 0, DummyClassLoader.BUFFER_SIZE)) != -1) {
				out.write(buffer, 0, n);
			}
			classBytes = out.toByteArray();
		} catch (final IOException ioe) {
			throw new RuntimeException("Unable to read src/test/resources/Dummy.class", ioe);
		}

		Class<?> cls;
		// 4. turn the byte array into a Class
		try {
			cls = this.defineClass(null, classBytes, 0, classBytes.length);
			if (resolve) {
				this.resolveClass(cls);
			}
		} catch (final SecurityException e) {
			// loading core java classes such as java.lang.String
			// is prohibited, throws java.lang.SecurityException.
			// delegate to parent if not allowed to load class
			cls = super.loadClass(className, resolve);
		}
		this.loadedClass = cls;

		return cls;
	}


	@Override
	public InputStream getResourceAsStream(final String resource) {
		if (this.dummyURLs == 2) {
			try {
				return new FileInputStream(new File("src/test/resources/not.properties"));
			} catch (final FileNotFoundException e) {
				e.printStackTrace();
				return null;
			}
		}
		return this.dummyURLs == 0 ? new InputStream() {


			@Override
			public int read() throws IOException {
				throw new IOException("ioio");
			}
		} : null;
	}


	@Override
	public String toString() {
		return "dummy one !";
	}

}
