/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.impl.parser;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.HashMap;

import javax.xml.parsers.ParserConfigurationException;

import junit.framework.Assert;

import org.junit.Test;

public class ParserTest {

	@Test
	public void testParserClassCastException() throws ParserConfigurationException, SecurityException, IllegalArgumentException {
		TypeParser<String> parser = Parsers.getParser(String.class);
		final HashMap<String, Object> parsers = new HashMap<String, Object>();
		parsers.put("java.lang.String", "nones");
		ReflectChanger.setField(null, Parsers.class, "parsers", parsers, true);
		try{
			Parsers.getParser(String.class);
			Assert.fail("should throw a class cast exception");
		}catch(ClassCastException cce){
			// Normal
		}finally{
			// reset parser
			parsers.clear();
			parsers.put("java.lang.String", parser);
		}
		
	}


	@Test
	public void testLoader() throws SecurityException, NoSuchMethodException, IllegalArgumentException, IllegalAccessException, InvocationTargetException {
		// original system classloader
		final ClassLoader original = ClassLoader.getSystemClassLoader();
		final DummyClassLoader dummy = new DummyClassLoader(original, ".*RDFTransparentStringTypeParser");

		ReflectChanger.setSystemClassLoader(dummy);

		try {
			final Class<?> parsersClass = dummy.loadClass(" org.ow2.weblab.core.helper.impl.parser.Parsers");
			final Method m = parsersClass.getDeclaredMethod("getParser", Class.class);
			m.invoke(null, String.class);
			Assert.fail();
		} catch (final Exception e1) {
			Assert.assertNotNull(e1);
		}


		// reopen static load of properties

		Parsers.strict = false;
		final Method m = Parsers.class.getDeclaredMethod("loadParsers");
		m.setAccessible(true);
		HashMap<?, ?> parsers = (HashMap<?, ?>)m.invoke(null);
		Assert.assertTrue(parsers.isEmpty());
		Parsers.strict = true;
		parsers = (HashMap<?, ?>)m.invoke(null);
		Assert.assertTrue(parsers.isEmpty());
		dummy.dummyURLs = 1;
		parsers = (HashMap<?, ?>)m.invoke(null);
		Assert.assertNotNull(parsers.get("java.lang.String"));
		Assert.assertTrue(parsers.get("java.lang.String").getClass().getName().contains("Dummy"));
		dummy.dummyURLs = 2;
		parsers = (HashMap<?, ?>)m.invoke(null);
		Assert.assertNull(parsers.get("java.lang.Number"));
		Assert.assertNotNull(parsers.get("java.lang.String"));
		Assert.assertTrue(parsers.get("java.lang.String").getClass().getName().contains("Dummy"));
		dummy.dummyURLs = 0;
		parsers = (HashMap<?, ?>)m.invoke(null);
		Assert.assertTrue(parsers.isEmpty());
		
		ReflectChanger.setSystemClassLoader(original);
		
	}


	@Test
	public void testLoad() throws IllegalArgumentException, IllegalAccessException, InvocationTargetException, SecurityException, NoSuchMethodException {
		// reopen static load of properties
		Parsers.strict = true;
		final Method m = Parsers.class.getDeclaredMethod("load", Object.class);
		m.setAccessible(true);
		m.invoke(null, "");
		m.invoke(null, ClassLoader.class.getName());
	}

	@Test
	public void testParsers(){
		RDFTransparentStringTypeParser ps = new RDFTransparentStringTypeParser();
		Assert.assertTrue(ps.matches("any String"));
		RDFIntegerTypeParser pi = new RDFIntegerTypeParser();
		Assert.assertTrue(pi.matches("\"12110\"^^xsd:int"));
		Assert.assertTrue(pi.matches("\"12110\"^^xsd:integer@fr"));
		Assert.assertFalse(pi.matches("\"12110\"^^xsd:intege@fr"));
		
		RDFDateTypeParser pdate = new RDFDateTypeParser();
		Assert.assertTrue(pdate.matches("\"03/03/03\"^^xsd:date@en"));
		Assert.assertFalse(pdate.matches("\"03/03/03\"^^xsd:dat@en"));
		
		//System.out.println(pdate.parseTypeValue("2012-11-11T01:12:12Z", null, null));
		
		Parsers.strict = true;
		Assert.assertNull(pdate.parseValue(new Object()));
		Assert.assertNull(pdate.parseValue("fail"));
		
		Dummy dummy = new Dummy();
		Assert.assertNull(dummy.parseTypeValue(null, null, null));
		Assert.assertTrue(dummy.matches(null));
		
		
		try {
			Parsers.getParser(Object.class);
			Assert.fail("Can not instanciate parser on Object");
		} catch (ParserConfigurationException e) {
			// Normal
		}
	}
	
}
