/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.test;

import java.io.File;
import java.net.URI;
import java.util.Date;

import org.ow2.weblab.core.annotator.BaseAnnotator;
import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.factory.WebLabResourceFactory;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.ComposedResource;
import org.ow2.weblab.core.model.Document;
import org.ow2.weblab.core.model.ResultSet;
import org.ow2.weblab.core.model.processing.WProcessingAnnotator;

public final class ResourcesCreator {


	public static final File ANNOTATION = new File("target/annotation.xml");


	public static final File DOCUMENT = new File("target/document.xml");


	public static final File RESULT_SET = new File("target/resultSet.xml");


	public static final File COMPOSED_RESOURCE = new File("target/composedResource.xml");


	public static final File COMPOSED_RESOURCE2 = new File("target/composedResource2.xml");


	public static final File RESOURCE = new File("target/res_1.xml");


	public static void buildTestResources() throws WebLabCheckedException {

		final Document document = WebLabResourceFactory.createResource("i", "DOCUMENT", Document.class);
		final WProcessingAnnotator wp1 = new WProcessingAnnotator(document);
		wp1.writeType(URI.create("Document"));
		wp1.writeLabel("Document2");


		wp1.startInnerAnnotatorOn(URI.create("empty"));
		// wp1.writeType(URI.create("empty"));
		for (int i = 0; i < 45; i++) {
			wp1.writeLabel("empty" + i);
		}

		final Annotation annotation2 = new Annotation();
		annotation2.setUri("empty");
		final WProcessingAnnotator wp2 = new WProcessingAnnotator(URI.create("empty"), annotation2);
		wp2.writeGatheringDate(new Date());
		wp2.startSpecifyLanguage("fr");
		wp2.writeLabel("empty");
		wp2.writeBeenUpdatedBy(URI.create("uname:tester"));

		final ResultSet resultSet = WebLabResourceFactory.createResource("res", "set", ResultSet.class);
		resultSet.setPok(annotation2);

		final ComposedResource composedResource = WebLabResourceFactory.createResource("c", "p", ComposedResource.class);
		composedResource.getResource().add(resultSet);
		composedResource.getResource().add(document);

		final Document document3 = WebLabResourceFactory.createResource("3", "DOCUMENT", Document.class);
		final WProcessingAnnotator wp3 = new WProcessingAnnotator(document3);
		final URI geonames = URI.create("http://sws.geonames.org/630673/");
		wp3.startInnerAnnotatorOn(URI.create("http://www.virtuoso.eu/ontology/instances/Location#black_sea"));
		wp3.writeType(geonames);
		wp3.startInnerAnnotatorOn(URI.create("itm:n#_101339"));
		wp3.writeType(geonames);

		final Annotation annotation3 = new Annotation();
		annotation3.setUri("empty3");
		URI itemType = URI.create("http://www.weblab-project.org/ontologies/stanag2433.owl#Event");
		BaseAnnotator ba = new BaseAnnotator(URI.create("itm:n#_100282"), annotation3);
		ba.writeType(itemType);
		ba.writeLabel("test1");
		ba.startInnerAnnotatorOn(URI.create("itm:n#_100283"));
		ba.writeType(itemType);
		ba.writeLabel("test");
		ba.startInnerAnnotatorOn(URI.create("itm:n#_100284"));
		ba.writeType(itemType);
		final ComposedResource composedResource2 = WebLabResourceFactory.createResource("c2", "p", ComposedResource.class);
		composedResource2.getResource().add(annotation3);

		final WebLabMarshaller marshaller = new WebLabMarshaller();
		marshaller.marshalResource(annotation2, ANNOTATION);
		marshaller.marshalResource(document, DOCUMENT);
		marshaller.marshalResource(resultSet, RESULT_SET);
		marshaller.marshalResource(composedResource, COMPOSED_RESOURCE);
		marshaller.marshalResource(document3, RESOURCE);
		marshaller.marshalResource(composedResource2, COMPOSED_RESOURCE2);
	}

}
