/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.test;

import java.io.File;
import java.util.List;

import junit.framework.Assert;

import org.junit.BeforeClass;
import org.junit.Test;
import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.extended.ontologies.RDFS;
import org.ow2.weblab.core.helper.impl.AdvancedSelector;
import org.ow2.weblab.core.helper.impl.RDFSelectorFactory;
import org.ow2.weblab.core.helper.impl.Statements;
import org.ow2.weblab.core.model.ComposedResource;
import org.ow2.weblab.core.model.ResultSet;

public class SortedTest {

	@BeforeClass
	public static void buildResources() throws WebLabCheckedException {
		if (!ResourcesCreator.DOCUMENT.exists() ||
			!ResourcesCreator.COMPOSED_RESOURCE2.exists() ||
			!ResourcesCreator.COMPOSED_RESOURCE.exists()  ||
			!ResourcesCreator.RESULT_SET.exists()  ||
			!ResourcesCreator.COMPOSED_RESOURCE.exists()  ||
			!ResourcesCreator.ANNOTATION.exists()) {
			ResourcesCreator.buildTestResources();
		}
	}

	@Test
	public void testMultiResult() throws WebLabCheckedException {
		buildResources();
		final AdvancedSelector rs = RDFSelectorFactory.getSelector(true);
		final ComposedResource rc = new WebLabMarshaller().unmarshal(ResourcesCreator.COMPOSED_RESOURCE2, ComposedResource.class);
		final Statements wtm = rs.searchFor(rc);
		
		List<String> luri = wtm.sortBy(RDFS.LABEL, Statements.ASC);
		Assert.assertTrue(luri.size() == 2);
		Assert.assertTrue(luri.get(0).equals("itm:n#_100282"));
		
		luri = wtm.sortBy(RDFS.LABEL, Statements.DESC);
		Assert.assertTrue(luri.size() == 2);
		Assert.assertTrue(luri.get(0).equals("itm:n#_100283"));
	}


	@Test
	public void testMultiResultFiltered() throws WebLabCheckedException {
		buildResources();
		final AdvancedSelector rs = RDFSelectorFactory.getSelector(true);
		final ResultSet rset = new WebLabMarshaller().unmarshal(ResourcesCreator.COMPOSED_RESOURCE2, ResultSet.class);
		final Statements wtm = rs.searchFor(rset);
		List<String> luri = wtm.sortBy(RDFS.LABEL, Statements.ASC, true);
		Assert.assertTrue(luri.size() == 3);
		Assert.assertEquals("itm:n#_100282", luri.get(0));
		Assert.assertEquals("itm:n#_100284", luri.get(2));

		luri = wtm.sortBy(RDFS.LABEL, Statements.DESC, true);
		Assert.assertTrue(luri.size() == 3);
		Assert.assertEquals("itm:n#_100283", luri.get(0));
		Assert.assertEquals("itm:n#_100284", luri.get(2));
	}

}
