/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.test;

import junit.framework.Assert;

import org.junit.BeforeClass;
import org.junit.Test;
import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.factory.WebLabResourceFactory;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.helper.impl.AdvancedSelector;
import org.ow2.weblab.core.helper.impl.RDFSelectorFactory;
import org.ow2.weblab.core.helper.impl.Statements;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.core.model.ResultSet;

public class WebLabObjectsTest {


	@BeforeClass
	public static void buildResources() throws WebLabCheckedException {
		if (!ResourcesCreator.ANNOTATION.exists()) {
			ResourcesCreator.buildTestResources();
		}
	}


	@Test
	public void testModel() throws WebLabCheckedException {
		final PieceOfKnowledge pok = WebLabResourceFactory.createResource("weblab://myPOKID/", "resPOKID", PieceOfKnowledge.class);
		pok.setUri("weblab://fileRepository/1240244394936/res_6#a1-a0");

		final ResultSet rs = WebLabResourceFactory.createResource("weblab://myID/", "resID", ResultSet.class);
		rs.setUri("weblab://fileRepository/1240244394936/res_6");
		final Annotation a = new WebLabMarshaller().unmarshal(ResourcesCreator.ANNOTATION, Annotation.class);
		rs.getAnnotation().add(a);
		final Object data = a.getData();
		pok.setData(data);

		final AdvancedSelector rdfs = RDFSelectorFactory.getSelector(true);
		Statements m = rdfs.searchFor(rs);
		Assert.assertEquals(1, m.size());
		m = rdfs.searchFor(pok);
		Assert.assertEquals(1, m.size());

	}


	@Test
	public void testResultSet() throws WebLabCheckedException {
		Resource rs = null;
		final WebLabMarshaller marsh = new WebLabMarshaller();
		rs = marsh.unmarshal(ResourcesCreator.RESULT_SET, ResultSet.class);
		final AdvancedSelector rdfs = RDFSelectorFactory.getSelector(true);

		final String[] filter = new String[] { "http://weblab-project.org/core/model/property/hasDescription",
				"http://weblab-project.org/core/model/property/hasRank", "http://weblab-project.org/core/model/search/property/isLinkedTo",
				"http://weblab-project.org/core/model/property/extracted/concept/visual", "http://purl.org/dc/elements/1.1/title",
				"http://purl.org/dc/elements/1.1/creator", "http://purl.org/dc/elements/1.1/subject", "http://purl.org/dc/elements/1.1/description",
				"http://purl.org/dc/elements/1.1/date", "http://purl.org/dc/elements/1.1/language", "http://purl.org/dc/elements/1.1/publisher",
				"http://purl.org/dc/elements/1.1/contibutor", "http://purl.org/dc/elements/1.1/type", "http://purl.org/dc/elements/1.1/format",
				"http://purl.org/dc/elements/1.1/identifier", "http://purl.org/dc/elements/1.1/source", "http://purl.org/dc/elements/1.1/relation",
				"http://purl.org/dc/elements/1.1/coverage", "http://purl.org/dc/elements/1.1/right",
				"http://weblab-project.org/core/model/property/hasNativeContent", "http://weblab-project.org/core/model/property/hasNormalisedContent",
				"http://weblab-project.org/core/model/property/isGeneratedFrom", "http://weblab-project.org/core/model/property/isProducedFrom",
				"http://weblab-project.org/core/model/property/isResultOf", "http://weblab-project.org/core/model/property/hasHitScore",
				"http://weblab-project.org/core/model/property/hasNumberOfResults", "http://weblab-project.org/core/model/property/isExposedAs",
				"http://purl.org/dc/terms/extent", "http://purl.org/dc/terms/modified", "http://purl.org/dc/terms/created",
				"http://weblab-project.org/core/model/property/hasCrawlingDate", "http://weblab-project.org/core/model/property/crawler/projectName",
				"http://weblab-project.org/core/model/property/hasOriginalFileSize", "http://weblab-project.org/core/model/property/refersTo",
				"http://www.w3.org/2000/01/rdf-schema#seeAlso", "http://www.w3.org/1999/02/22-rdf-syntax-ns#type" };
		final Statements m = rdfs.searchFor(rs, filter);
		Assert.assertTrue(m.isEmpty());
	}

}
