/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 CASSIDIAN
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.core.helper;

import java.net.URI;
import java.net.URISyntaxException;
import java.util.List;

import junit.framework.Assert;

import org.junit.Test;
import org.ow2.weblab.core.extended.factory.WebLabResourceFactory;
import org.ow2.weblab.core.extended.ontologies.RDFS;
import org.ow2.weblab.core.helper.impl.JenaPoKHelper;
import org.ow2.weblab.core.helper.impl.JenaResourceHelper;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.Text;
import org.ow2.weblab.rdf.Value;

public class JenaCompatibility {


	@Test
	public void testRead() throws URISyntaxException {

		/*
		 * Write with annotators
		 * Read with jena
		 */
		final Text text = WebLabResourceFactory.createResource("idfact", "myDoc", Text.class);
		text.setContent("London.");

		final WGeonamesAnnotator geoa = new WGeonamesAnnotator(text);

		final URI londonGeonamesURI = new URI("http://sws.geonames.org/2643743/");

		// Create a geographic entity in the document from an external ontology
		geoa.startInnerAnnotatorOn(londonGeonamesURI);

		geoa.startSpecifyLanguage("arc");
		geoa.writeLabel("ܠܘܢܕܘܢ ");
		geoa.startSpecifyLanguage("fr");
		geoa.writeLabel("Londres");
		geoa.endSpecifyLanguage();
		geoa.writeLabel("London");

		// Read with Jena
		final ResourceHelper rh = new JenaResourceHelper(text);
		List<String> values = rh.getLitsOnPredSubj(londonGeonamesURI.toString(), RDFS.LABEL);
		Assert.assertEquals(3, values.size());
		Assert.assertEquals("London", values.get(0));
		values = rh.getLitsOnPredSubj(londonGeonamesURI.toString(), RDFS.LABEL, "arc");
		Assert.assertEquals(1, values.size());
		Assert.assertEquals("ܠܘܢܕܘܢ ", values.get(0));
	}


	@Test
	public void testWrite() throws URISyntaxException {
		/**
		 * Write with jena
		 * Read with annotators
		 */
		final Text text = WebLabResourceFactory.createResource("idfact", "myDoc", Text.class);
		text.setContent("London.");

		final URI londonGeonamesURI = new URI("http://sws.geonames.org/2643743/");

		final Annotation a = WebLabResourceFactory.createAndLinkAnnotation(text);

		final PoKHelper ph = new JenaPoKHelper(a);

		ph.createLitStat(londonGeonamesURI.toString(), RDFS.LABEL, "London");
		ph.createLitStat(londonGeonamesURI.toString(), RDFS.LABEL, "Londres", "fr");
		ph.createLitStat(londonGeonamesURI.toString(), RDFS.LABEL, "ܠܘܢܕܘܢ ", "arc");

		// read with annotators
		final WGeonamesAnnotator geoa = new WGeonamesAnnotator(londonGeonamesURI, a);

		final Value<String> values = geoa.readLabel();

		Assert.assertEquals(3, values.size());
		Assert.assertEquals("ܠܘܢܕܘܢ ", values.firstTypedValue("arc"));
	}

}
