/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 CASSIDIAN
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.core.helper.impl;

import java.io.File;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.Callable;

import junit.framework.Assert;

import org.apache.commons.logging.LogFactory;
import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.helper.ResourceHelper;
import org.ow2.weblab.core.model.Resource;

public class PoKHelperComplexThread implements Callable<Boolean> {


	private final String[] properties = { "http://purl.org/dc/elements/1.1/title", "http://purl.org/dc/elements/1.1/creator",
			"http://purl.org/dc/elements/1.1/subject", "http://purl.org/dc/elements/1.1/date", "http://purl.org/dc/elements/1.1/type",
			"http://purl.org/dc/elements/1.1/format", "http://purl.org/dc/elements/1.1/identifier", "http://purl.org/dc/elements/1.1/source",
			"http://purl.org/dc/elements/1.1/language", "http://purl.org/dc/terms/extent", "http://purl.org/dc/terms/modified",
			"http://purl.org/dc/terms/created", "http://weblab-project.org/core/model/property/hasNativeContent",
			"http://weblab-project.org/core/model/property/isExposedAs", "http://weblab-project.org/core/model/property/isProducedFrom" };


	private final String resourceFolder;


	private final int id;


	private int cpt = 0;


	private long durationSum;


	public PoKHelperComplexThread(final int id, final String resourceFolder) {
		this.id = id;
		this.resourceFolder = resourceFolder;
	}


	@Override
	public Boolean call() {
		LogFactory.getLog(this.getClass()).info("Running [" + this.getClass().getSimpleName() + "]-" + this.id + "...");
		this.processFile(new File(this.resourceFolder));
		LogFactory.getLog(this.getClass()).info("[" + this.getClass().getSimpleName() + "]-" + this.id + " is done.");
		return Boolean.TRUE;
	}


	private void processFile(final File toBeProcessed) {
		if (toBeProcessed.isDirectory()) {
			for (final String f : toBeProcessed.list()) {
				if (f.endsWith(".xml")) {
					this.processFile(new File(toBeProcessed, f));
				}
			}
		} else {
			try {
				final Resource r = new WebLabMarshaller().unmarshal(toBeProcessed, Resource.class);
				final long start = System.currentTimeMillis();
				this.process(r);
				this.durationSum += System.currentTimeMillis() - start;
				this.cpt++;
			} catch (final WebLabCheckedException e) {
				LogFactory.getLog(this.getClass()).error("Cannot process resource [" + toBeProcessed.getAbsolutePath() + "] : " + e.getMessage());
				Assert.fail();
			}
		}
	}


	private void process(final Resource r) throws WebLabCheckedException {
		if (r == null) {
			throw new WebLabCheckedException("Input Resource is null.");
		}

		LogFactory.getLog(this.getClass()).info("[" + this.getClass().getSimpleName() + "]-" + this.id + " is processing Resource [" + r.getUri() + "]...");

		ResourceHelper helper = null;

		final URI uri;
		try {
			uri = new URI(r.getUri());
		} catch (final URISyntaxException e) {
			throw new WebLabCheckedException("Resource to process does not have valid URI.", e);
		}
		Assert.assertNotNull(uri);
		final List<String> predList = new ArrayList<String>();
		for (final String property : this.properties) {
			final StringBuffer concatenationOfText = new StringBuffer();

			if (helper == null) {
				helper = new JenaResourceHelper(r);
			}

			predList.addAll(helper.getLitsOnPredSubj(r.getUri(), property));
			predList.addAll(helper.getRessOnPredSubj(r.getUri(), property));
			for (final String p : predList) {
				concatenationOfText.append(p + "\n");
			}
		}

		LogFactory.getLog(this.getClass()).info("[" + this.getClass().getSimpleName() + "]-" + this.id + " has processed [" + r.getUri() + "].");
	}


	public int getCpt() {
		return this.cpt;
	}


	public long getMeanDurationTime() {
		return this.durationSum / this.cpt;
	}


	public long getDurationSum() {
		return this.durationSum;
	}


	public int getId() {
		return this.id;
	}
}
