/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 CASSIDIAN
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.core.helper.impl;

import java.util.Collection;
import java.util.concurrent.Callable;

import junit.framework.Assert;

import org.ow2.weblab.core.extended.factory.WebLabResourceFactory;
import org.ow2.weblab.core.extended.ontologies.RDF;
import org.ow2.weblab.core.extended.ontologies.RDFS;
import org.ow2.weblab.core.helper.PoKHelper;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.core.model.StringQuery;

import com.hp.hpl.jena.vocabulary.OWL;

public class PoKHelperThread implements Callable<Boolean> {


	private final PoKHelper helper;


	private final Resource res;


	private final Annotation a;


	public PoKHelperThread() {
		this.res = WebLabResourceFactory.createResource("annotation.helper.testCase", "res1", StringQuery.class);
		this.a = WebLabResourceFactory.createAndLinkAnnotation(this.res);
		this.helper = new JenaPoKHelper(this.a);
	}


	@Override
	public Boolean call() {
		this.helper.setAutoCommitMode(true);
		this.helper.createLitStat(this.res.getUri(), RDFS.LABEL, "label");
		this.helper.createLitStat(this.res.getUri(), RDFS.LABEL, "label2");
		Collection<String> values = this.helper.getLitsOnPredSubj(this.res.getUri(), RDFS.LABEL);
		Assert.assertEquals(2, values.size());
		Assert.assertTrue(values.contains("label"));
		Assert.assertTrue(values.contains("label2"));

		values = this.helper.getRessOnPredSubj(this.res.getUri(), RDFS.LABEL);
		Assert.assertEquals(0, values.size());

		this.helper.createResStat(this.res.getUri(), RDF.TYPE, OWL.Class.getURI());
		values = this.helper.getRessOnPredSubj(this.res.getUri(), RDF.TYPE);
		Assert.assertEquals(1, values.size());
		Assert.assertTrue(values.contains(OWL.Class.getURI()));
		return Boolean.TRUE;
	}

}
