package org.ow2.weblab.utils;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

import junit.framework.Assert;

/**
 * This class allow to automatically generate and check test on supported methods on any object.
 * 
 * @author asaval
 *
 */
public class ReflexiveGenerator<T> {

	private String sdefault;
	private Map mapdefault;
	
	public ReflexiveGenerator(){
		this("test", new HashMap());
	}
	
	public ReflexiveGenerator(String sdefault, Map mapdefault){
		this.sdefault = sdefault;
		this.mapdefault = mapdefault;
	}
	
	private List<Object[]> generateParameters(final Class<?>[] classes){
		int number = classes.length;
		List<Object[]> objects = new LinkedList<Object[]>();
		objects.add(createParameters(classes, -1));
		int escape = 0;
		for(int i = 0;i<number;i++){
			objects.add(createParameters(classes, escape));
			escape++;
		}
		return objects;
	}
	
	private <T> boolean[] createParams(final boolean value, final int number, final int escape){
		boolean[] o = new boolean[number];
		for(int j=0;j<number;j++){
			o[j] = escape == j?null:value;
		}
		return o;
	}
	

	
	private void methodApply(final T object , final Method method, final boolean[] cs) {
		Class<?>[] classes = method.getParameterTypes(); 
		int number = classes.length;
		List<Object[]> testlist = generateParameters(classes);
		// the first element is always ok, all other should fail.
		
		// check if we use custom results
		boolean[] shouldSucceed;
		if (cs == null || (cs.length != testlist.size())){
			shouldSucceed = createParams(false, number+1, -1);
			shouldSucceed[0] = true;
		}else{
			shouldSucceed = cs;
		}
		
		int i = 0;
		for(Object[] params:testlist){
			try {
				method.invoke(object, params);
				if (!shouldSucceed[i]){
					Assert.fail(print(params)+" should have failed "+method+" on test "+i+" shouldSucceed["+shouldSucceed[i]+"]");
				}
			} catch (IllegalArgumentException e) {
				e.printStackTrace();
			} catch (IllegalAccessException e) {
				//e.printStackTrace();
			} catch (InvocationTargetException e) {
				if (shouldSucceed[i]){
					e.printStackTrace();
					Assert.fail(print(params)+" should not have failed "+method+" on test "+i+" shouldSucceed["+shouldSucceed[i]+"]");
				}
			}
			i++;
		}
		
	}
	
	public String print(final Object[] objects){
		String res = "[";
		for(Object o:objects){
			res +=o+",";
		}
		return res+"]";
	}

	public void apply(final T object, final Map<String, boolean[]> customResult) {
		apply(object, customResult, false);
	}
	
	public void apply(final T object, final Map<String, boolean[]> customResult, boolean debug) {
		
		final Method[] methods = object.getClass().getDeclaredMethods();
		
		for(Method method:methods){
			Class<?>[] parameters = method.getParameterTypes();
			if (isSupportedParameters(parameters)){
				// test method
				if (debug){
					System.out.println(method);
				}
				String name = method.getName();
				if (!name.equals("close") && !name.equals("finalize") && !name.equals("getRdfXml") ){// TODO: correct getRdfXml test 
					methodApply(object, method, customResult.get(method.getName()+parameters.length));
				}
			}else{
				// TODO : add test for unsupported automated test methods
				if (debug){
					System.out.println(method+" i s not reflexive supported, add default type support to isSupportedParameters(Class<?>[] classes) and change createParameters(final Class<?>[] classes, String str, Map<?,?> map, final int escape)");
				}
			}
		}
	}

	
	private boolean isSupportedParameters(Class<?>[] classes){
		for(Class<?> c:classes){
			if (!c.isInstance("") && !c.getCanonicalName().equals(Map.class.getCanonicalName())){
				return false;
			}
		}
		return true;
	}
	
	private Object[] createParameters(final Class<?>[] classes, final int escape){
		String str = this.sdefault;
		Map map = this.mapdefault;
		
		Object[] res = new Object[classes.length];
		for(int i = 0;i<classes.length;i++){
			if (i != escape){
				if (classes[i].isInstance(str)){
					res[i] = str;
				}else if (classes[i].isAssignableFrom(Map.class)){
					res[i] = map;
				}
			}
		}
		return res;
	}
}
