/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.core.helpers.samples;

import java.io.File;
import java.text.SimpleDateFormat;
import java.util.Date;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.extended.ontologies.DublinCore;
import org.ow2.weblab.core.extended.ontologies.WebLabProcessing;
import org.ow2.weblab.core.helper.impl.RDFSelectorFactory;
import org.ow2.weblab.core.helper.impl.Results;
import org.ow2.weblab.core.helper.impl.SimpleSelector;
import org.ow2.weblab.core.model.Document;
import org.ow2.weblab.core.model.processing.WProcessingAnnotator;


/**
 * Class that showing how to retrieve RDF properties and values from RDF data in WebLab Resources.
 */
public class RDFSelection {

	
	Log log = LogFactory.getLog(RDFSelection.class); 

	/**
	 * Selection of a simple property with annotator.
	 */
	public void annotatorPropertySelection() throws WebLabCheckedException {

		final WebLabMarshaller marshaler = new WebLabMarshaller();
		final Document document = marshaler.unmarshal(new File("target/res_584697-v3.xml"), Document.class);

		final WProcessingAnnotator wpAnnot = new WProcessingAnnotator(document);

		final Date gatheringDate = wpAnnot.readGatheringDate().firstTypedValue();

		final SimpleDateFormat hour_sdf = new SimpleDateFormat("hh:mm:ss");
		final SimpleDateFormat day_sdf = new SimpleDateFormat("E d MMM");

		log.info("The day of the gathering of the document is : " + day_sdf.format(gatheringDate));
		log.info("The time of the gathering of the document is : " + hour_sdf.format(gatheringDate));

	}


	/**
	 * Selection of a simple property with helper.
	 */
	public void helperPropertySelection() throws WebLabCheckedException {

		final WebLabMarshaller marshaler = new WebLabMarshaller();
		final Document document = marshaler.unmarshal(new File("target/doc_annot.xml"), Document.class);

		final SimpleSelector selector = RDFSelectorFactory.getSelector();

		final Results results = selector.select(document);

		final String creator = results.getTypedValue(document.getUri(), DublinCore.CREATOR_PROPERTY_NAME, String.class);

		log.info("Document creator is " + creator);

	}


	/**
	 * Several selection at the same time
	 * 
	 */
	public void propertiesSelection() throws WebLabCheckedException {

		final WebLabMarshaller marshaler = new WebLabMarshaller();
		final Document document = marshaler.unmarshal(new File("target/res_584697-v7.xml"), Document.class);

		final SimpleSelector selector = RDFSelectorFactory.getSelector();

		final Results results = selector.select(document, WebLabProcessing.HAS_NORMALISED_CONTENT);

		for (final String subject : results.keySet()) {
			log.info("The resource " + subject + " has a normalised content : "
					+ results.getTypedValue(subject, WebLabProcessing.HAS_NORMALISED_CONTENT, String.class));
		}

	}

}
